Class: Google::Cloud::SecurityCenter::V2::DetectorReference

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/securitycenter/v2/agent_anomaly.rb

Overview

Represents a reference to a specific anomaly detector.

Defined Under Namespace

Modules: Severity

Instance Attribute Summary collapse

Instance Attribute Details

#detector_id::String

Returns The unique identifier of the detector.

Returns:

  • (::String)

    The unique identifier of the detector.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'proto_docs/google/cloud/securitycenter/v2/agent_anomaly.rb', line 64

class DetectorReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Severity levels for detectors.
  module Severity
    # Unspecified severity.
    SEVERITY_UNSPECIFIED = 0

    # Critical severity.
    CRITICAL = 1

    # High severity.
    HIGH = 2

    # Medium severity.
    MEDIUM = 3

    # Low severity.
    LOW = 4
  end
end

#display_name::String

Returns A human readable name for the detector, providing context on its purpose. For example, "ASI02: Tool Misuse", or "Excessive API Calls".

Returns:

  • (::String)

    A human readable name for the detector, providing context on its purpose. For example, "ASI02: Tool Misuse", or "Excessive API Calls".



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'proto_docs/google/cloud/securitycenter/v2/agent_anomaly.rb', line 64

class DetectorReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Severity levels for detectors.
  module Severity
    # Unspecified severity.
    SEVERITY_UNSPECIFIED = 0

    # Critical severity.
    CRITICAL = 1

    # High severity.
    HIGH = 2

    # Medium severity.
    MEDIUM = 3

    # Low severity.
    LOW = 4
  end
end

#explanation::String

Returns A detailed explanation generated by an LLM or the detector itself, describing why this specific anomaly was flagged. This provides rationale and context for the detection.

Returns:

  • (::String)

    A detailed explanation generated by an LLM or the detector itself, describing why this specific anomaly was flagged. This provides rationale and context for the detection.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'proto_docs/google/cloud/securitycenter/v2/agent_anomaly.rb', line 64

class DetectorReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Severity levels for detectors.
  module Severity
    # Unspecified severity.
    SEVERITY_UNSPECIFIED = 0

    # Critical severity.
    CRITICAL = 1

    # High severity.
    HIGH = 2

    # Medium severity.
    MEDIUM = 3

    # Low severity.
    LOW = 4
  end
end

#recommendation::String

Returns Recommended steps or actions to remediate or investigate the anomaly flagged by this detector. These could include configuration changes, code adjustments, or further diagnostic procedures.

Returns:

  • (::String)

    Recommended steps or actions to remediate or investigate the anomaly flagged by this detector. These could include configuration changes, code adjustments, or further diagnostic procedures.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'proto_docs/google/cloud/securitycenter/v2/agent_anomaly.rb', line 64

class DetectorReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Severity levels for detectors.
  module Severity
    # Unspecified severity.
    SEVERITY_UNSPECIFIED = 0

    # Critical severity.
    CRITICAL = 1

    # High severity.
    HIGH = 2

    # Medium severity.
    MEDIUM = 3

    # Low severity.
    LOW = 4
  end
end

#severity::Google::Cloud::SecurityCenter::V2::DetectorReference::Severity

Returns The severity of the detector.

Returns:



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'proto_docs/google/cloud/securitycenter/v2/agent_anomaly.rb', line 64

class DetectorReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Severity levels for detectors.
  module Severity
    # Unspecified severity.
    SEVERITY_UNSPECIFIED = 0

    # Critical severity.
    CRITICAL = 1

    # High severity.
    HIGH = 2

    # Medium severity.
    MEDIUM = 3

    # Low severity.
    LOW = 4
  end
end